files

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 16, 2026 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package files manages file uploads and downloads for Codat companies.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Resource

type Resource struct {
	resource.Base
}

Resource manages company files.

func New

func New(hc *httpclient.Client) *Resource

New constructs a Resource.

func (*Resource) Download

func (r *Resource) Download(ctx context.Context, companyID domain.CompanyID, date string) ([]byte, error)

Download downloads all files for a company as a ZIP archive.

func (*Resource) List

func (r *Resource) List(ctx context.Context, companyID domain.CompanyID) ([]domain.FileMetadata, error)

List returns the file metadata for a company.

func (*Resource) Upload

func (r *Resource) Upload(ctx context.Context, companyID domain.CompanyID, connectionID domain.ConnectionID, data []byte, contentType string) error

Upload uploads a file for a company's connection.

Jump to