Documentation
¶
Overview ¶
Package files manages file uploads and downloads for Codat companies.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Resource ¶
Resource manages company files.
func (*Resource) Download ¶
func (r *Resource) Download(ctx context.Context, companyID domain.CompanyID, date string) ([]byte, error)
Download downloads all files for a company as a ZIP archive.
Click to show internal directories.
Click to hide internal directories.